@@ -19,6 +19,8 @@
 #' @param weight_production Logical vector of length 1. `TRUE` defaults to
 #' outputting production, weighted by relative loan-size. Set to `FALSE` to
 #' output the unweighted production values.
+#' @param increasing_or_decreasing A data frame like
+#' [r2dii.data::increasing_or_decreasing].
 #' @param ald `r lifecycle::badge('superseded')` `ald` has been superseded by
 #'   `abcd`.
 #'
@@ -31,6 +33,7 @@
 #' @family functions to calculate scenario targets
 #'
 #' @examples
+#' \dontrun{
 #' installed <- requireNamespace("r2dii.data", quietly = TRUE) &&
 #'   requireNamespace("r2dii.match", quietly = TRUE) &&
 #'   packageVersion("r2dii.match") >= "0.1.0"
@@ -72,6 +75,7 @@
 #'       weight_production = FALSE
 #'     )
 #' }
+#' }
 target_market_share <- function(data,
                                 abcd,
                                 scenario,
@@ -79,6 +83,7 @@ target_market_share <- function(data,
                                 use_credit_limit = FALSE,
                                 by_company = FALSE,
                                 weight_production = TRUE,
+                                increasing_or_decreasing = r2dii.data::increasing_or_decreasing,
                                 ald = deprecated()) {
   stopifnot(
     is.data.frame(data),
@@ -156,10 +161,9 @@ target_market_share <- function(data,
 
   data <- calculate_targets(data)
 
-  green_or_brown <- r2dii.data::green_or_brown
   tmsr_or_smsp <- tmsr_or_smsp()
 
-  data <- pick_sms_or_tms_target(data, green_or_brown, tmsr_or_smsp)
+  data <- pick_sms_or_tms_target(data, increasing_or_decreasing, tmsr_or_smsp)
 
   if (nrow(data) == 0) {
     return(empty_target_market_share_output())
@@ -222,21 +226,21 @@ target_market_share <- function(data,
   data <- data %>%
     dplyr::bind_rows(relevant_corporate_economy)
 
-  data <- add_percentage_of_initial_production_by_scope(data, green_or_brown, tmsr_or_smsp, by_company)
+  data <- add_percentage_of_initial_production_by_scope(data, increasing_or_decreasing, tmsr_or_smsp, by_company)
 
   data %>%
     ungroup()
 }
 
 add_percentage_of_initial_production_by_scope <- function(data,
-                                                          green_or_brown,
+                                                          increasing_or_decreasing,
                                                           tmsr_or_smsp,
                                                           by_company) {
   data <- data %>%
-    left_join(green_or_brown, by = c("sector", "technology")) %>%
-    left_join(tmsr_or_smsp, by = "green_or_brown") %>%
+    left_join(increasing_or_decreasing, by = c("sector", "technology")) %>%
+    left_join(tmsr_or_smsp, by = "increasing_or_decreasing") %>%
     rename(target_name = "which_metric") %>%
-    select(-all_of("green_or_brown"))
+    select(-all_of("increasing_or_decreasing"))
 
   percent_by_sector_groups <- add_name_abcd_if_by_company(
     c("sector", "region", "scenario_source", "metric"),
@@ -331,7 +335,8 @@ calculate_abcd_benchmark <- function(abcd, region_isos, by_company) {
     mutate(plant_location = tolower(.data$plant_location)) %>%
     inner_join(
       region_isos,
-      by = c("plant_location" = "isos")
+      by = c("plant_location" = "isos"),
+      relationship = "many-to-many"
     ) %>%
     warn_if_has_zero_rows("Joining `region_isos` outputs 0 rows.") %>%
     # Return visibly
@@ -369,26 +374,26 @@ add_name_abcd_if_by_company <- function(list, by_company = FALSE) {
   list
 }
 
-pick_sms_or_tms_target <- function(data, green_or_brown, tmsr_or_smsp) {
+pick_sms_or_tms_target <- function(data, increasing_or_decreasing, tmsr_or_smsp) {
   data %>%
     left_join(tmsr_or_smsp, by = c(target_name = "which_metric")) %>%
     inner_join(
-      green_or_brown,
+      increasing_or_decreasing,
       by = c(
         sector_abcd = "sector",
         technology = "technology",
-        green_or_brown = "green_or_brown"
+        increasing_or_decreasing = "increasing_or_decreasing"
       )
     ) %>%
-    warn_if_has_zero_rows("Joining `r2dii.data::green_or_brown` outputs 0 rows") %>%
-    select(-all_of(c("target_name", "green_or_brown")))
+    warn_if_has_zero_rows("Joining `r2dii.data::increasing_or_decreasing` outputs 0 rows") %>%
+    select(-all_of(c("target_name", "increasing_or_decreasing")))
 }
 
 tmsr_or_smsp <- function() {
   dplyr::tribble(
-    ~which_metric, ~green_or_brown,
-    "tmsr_target_production", "brown",
-    "smsp_target_production", "green"
+    ~which_metric, ~increasing_or_decreasing,
+    "tmsr_target_production", "decreasing",
+    "smsp_target_production", "increasing"
   )
 }
 
